@@ -6,7 +6,7 @@ package Test::Signature;
 use strict;
 use Exporter;
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION = '1.04';
+$VERSION = '1.05';
 @ISA = qw( Exporter );
 @EXPORT = qw( signature_ok );
 @EXPORT_OK = qw( signature_force_ok );
@@ -17,45 +17,31 @@ my $test = Test::Builder->new();
 
 #line 76
 
+sub action_skip { $test->skip( $_[0] ) }
+sub action_ok   { $test->ok( 0, $_[0] ) }
+
 sub signature_ok
 {
     my $name  = shift || 'Valid signature';
     my $force = shift || 0;
+    my $action = $force ? \&action_ok : \&action_skip;
     SKIP: {
 	if ( !-s 'SIGNATURE' )
 	{
-	    $test->skip( "No SIGNATURE file found." );
-	}
-	elsif ( !eval { require Socket; Socket::inet_aton('pgp.mit.edu') })
-	{
-	    $test->skip( "Cannot connect to the keyserver." );
+	    $action->( "No SIGNATURE file found." );
 	}
 	elsif ( !eval { require Module::Signature; 1 } )
 	{
-	    if ($force)
-	    {
-		$test->ok(0, $name);
-		$test->diag(<<"EOF");
-You need Module::Signature for this distribution.
-With that, you can have the contents of the archive verified.
-EOF
-	    }
-	    else
-	    {
-		$test->skip( "No Module::Signature installed." );
-		$test->diag(<<"EOF");
-Next time around, consider installing Module::Signature,
-so you can verify the integrity of this distribution.
-EOF
-	    }
+            $action->(
+                "Next time around, consider installing Module::Signature, ".
+                "so you can verify the integrity of this distribution." );
+	}
+	elsif ( !eval { require Socket; Socket::inet_aton('pgp.mit.edu') })
+	{
+	    $action->( "Cannot connect to the keyserver." );
 	}
 	else
 	{
-	    $test->diag(<<"EOF");
-
-Using Module::Signature v$Module::Signature::VERSION
-
-EOF
 	    $test->ok(
 		Module::Signature::verify() == Module::Signature::SIGNATURE_OK()
 		=> $name);
@@ -63,7 +49,7 @@ EOF
     }
 }
 
-#line 137
+#line 123
 
 sub signature_force_ok
 {
@@ -73,4 +59,4 @@ sub signature_force_ok
 1;
 __END__
 
-#line 314
+#line 300
